import React, { useState } from 'react';
import { Td, Tr, Link, Select } from '@chakra-ui/react';
import { useTranslation } from 'react-i18next';

const statuses = [
  'pending' as const,
  'progress' as const,
  'working' as const,
  'canceled' as const,
  'complete' as const,
];

type GetArrItemType<ArrType> =
  ArrType extends Array<infer ItemType> ? ItemType : never;

export type OrderProps = {
  carNumber?: string;
  washTime?: string;
  orderDate?: string;
  status?: GetArrItemType<typeof statuses>;
  phone?: string;
  location?: string;
};

const OrderItem = ({
  carNumber,
  washTime,
  orderDate,
  status,
  phone,
  location,
}: OrderProps) => {
  const { t } = useTranslation('~', {
    keyPrefix: 'dry-wash.arm.order',
  });

  const [statusSelect, setStatus] = useState(status);

  return (
    <Tr>
      <Td>{carNumber}</Td>
      <Td>{washTime}</Td>
      <Td>{orderDate}</Td>
      <Td>
        <Select
          value={statusSelect}
          onChange={(e) => setStatus(e.target.value as OrderProps['status'])}
          placeholder={t(`status.placeholder`)}
        >
          {statuses.map((status) => (
            <option key={status} value={status}>
              {t(`status.${status}`)}
            </option>
          ))}
        </Select>
      </Td>
      <Td>
        <Link href='tel:'>{phone}</Link>
      </Td>
      <Td>{location}</Td>
    </Tr>
  );
};

export default OrderItem;
